@@ -1,7 +1,7 @@
 package Text::ANSI::NonWideUtil;
 
 our $DATE = '2015-08-20'; # DATE
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -46,7 +46,17 @@ Text::ANSI::NonWideUtil - Routines for text containing ANSI color codes (non-wid
 
 =head1 VERSION
 
-This document describes version 0.20 of Text::ANSI::NonWideUtil (from Perl distribution Text-ANSI-Util), released on 2015-08-20.
+This document describes version 0.21 of Text::ANSI::NonWideUtil (from Perl distribution Text-ANSI-Util), released on 2015-08-20.
+
+=head1 DESCRIPTION
+
+This module provides routines for dealing with text that contains ANSI color
+codes, e.g. for determining its length/width (excluding the color codes),
+stripping the color codes, extracting the color codes, and so on.
+
+There is also a wide variant: L<Text::ANSI::WideUtil>. The difference is that
+::WideUtil can handle wide (full-width) Unicode characters, while ::NonWideUtil
+can also handle normal/halfwidth/ASCII characters.
 
 =head1 FUNCTIONS
 
@@ -218,6 +228,10 @@ A bit like Perl's C<substr()>. If C<$replacement> is not specified, will return
 the substring. If C<$replacement> is specified, will return $text with the
 substring replaced by C<$replacement>.
 
+=head1 SEE ALSO
+
+L<Text::ANSI::WideUtil>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Text-ANSI-Util>.
